# bh1745 examples

## hex-colour.py

Converts the colour reading into a hex #FFFFFF colour code.

## raw-colour.py

Returns the raw colour values from the sensor.

## two-sensors.py

Demonstrates how to use two sensors simultaneously. You will need to *very carefully* cut the cuttable trace on the back of one of your sensors to change the i2c address.
